cumulusci.salesforce\_api.tests package
=======================================

Submodules
----------

cumulusci.salesforce\_api.tests.metadata\_test\_strings module
--------------------------------------------------------------

.. automodule:: cumulusci.salesforce_api.tests.metadata_test_strings
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.salesforce\_api.tests.test\_metadata module
-----------------------------------------------------

.. automodule:: cumulusci.salesforce_api.tests.test_metadata
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.salesforce\_api.tests.test\_package\_zip module
---------------------------------------------------------

.. automodule:: cumulusci.salesforce_api.tests.test_package_zip
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.salesforce_api.tests
    :members:
    :undoc-members:
    :show-inheritance:
